import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:slick/navigation/route_configuration.dart';
import 'package:slick/navigation/routes_base.dart';

class SlickScaffold extends ConsumerWidget {
  final Widget body;
  final String appBarTitle;
  final List<Widget> actions;
  final Widget leading;
  final Widget floatingActionButton;
  final bool showHeader;
  final bool showFooter;
  final bool centerBody;

  SlickScaffold({
    Key key,
    @required this.body,
    this.appBarTitle,
    this.actions,
    this.leading,
    this.floatingActionButton,
    this.showHeader = true,
    this.centerBody = false,
    this.showFooter = true,
  }) : super(key: key);

  @override
  Widget build(BuildContext context, ScopedReader watch) {
    var actionsWithButton = <Widget>[
      // Center(
      //   child: SlickElevatedButton(
      //     onPressed: () {},
      //     child: Row(
      //       children: [
      //         Text('Dashboard'),
      //         Container(
      //           height: 20,
      //           child: VerticalDivider(
      //             indent: 2,
      //             endIndent: 2,
      //             thickness: 0.3,
      //             color: Colors.white,
      //           ),
      //         ),
      //         Icon(Icons.account_circle_sharp),
      //       ],
      //     ),
      //   ),
      // )
    ];

    if (actions != null) actionsWithButton.addAll(actions);
    actionsWithButton.add(
      SizedBox(
        width: 32,
      ),
    );

    if (showHeader) {
      return Scaffold(
        drawer: drawer(context),
        appBar: AppBar(
          backgroundColor: Colors.white,
          //leading: leading,
          actions: actionsWithButton,
          //title: Text(appBarTitleToShow),

          flexibleSpace: header(),
          toolbarHeight: 150,
        ),
        body: wrappedBody(),
        floatingActionButton: Padding(
          padding: const EdgeInsets.only(
            bottom: 150,
          ),
          child: floatingActionButton,
        ),
      );
    } else {
      return Material(
        child: wrappedBody(),
      );
    }
  }

  Row header() {
    return Row(
      children: [
        Padding(
          padding: const EdgeInsets.only(left: 16.0),
          child: Center(
            child: Image.asset(
              'images/logo_h.png',
              width: 230,
            ),
          ),
        ),
      ],
    );
  }

  CustomScrollView wrappedBody() {
    return CustomScrollView(
      slivers: [
        SliverList(
          delegate: SliverChildListDelegate(
            [
              Column(
                mainAxisSize: MainAxisSize.min,
                crossAxisAlignment: centerBody
                    ? CrossAxisAlignment.center
                    : CrossAxisAlignment.start,
                children: [
                  // Padding(
                  //   padding: const EdgeInsets.only(
                  //     left: 16.0,
                  //     top: 32.0,
                  //     bottom: 16.0,
                  //   ),
                  //   child: SlickTitle(
                  //     labelText: appBarTitle ??
                  //         currentRouteSingleton.routeInformation.screenName,
                  //   ),
                  // ),
                  body,
                ],
              ),
            ],
          ),
        ),
        //if (showFooter)
        // SliverFillRemaining(
        //   hasScrollBody: false,
        //   child: Align(
        //     alignment: Alignment.bottomCenter,
        //     child: MoneyitFooter(),
        //   ),
        // )
      ],
    );
  }

  String get appBarTitleToShow {
    if (appBarTitle == null) return currentRouteSingleton.screenNameForRoute();
    return appBarTitle ?? '';
  }

  Drawer drawer(BuildContext context) {
    return Drawer(
      child: ListView(
        // Important: Remove any padding from the ListView.
        padding: EdgeInsets.zero,
        children: [
          DrawerHeader(
            child: Image.asset('images/logo_v.png'),
            decoration: BoxDecoration(
              color: Colors.green,
            ),
          ),
          Column(
            children: RoutesBase.menuRoutes()
                .map((routeInfo) => ListTile(
                      tileColor: Colors.grey.shade200,
                      title: Text(routeInfo.screenName),
                      onTap: () {
                        Navigator.pop(context); //hide drawer menu
                        currentRouteSingleton.navigate(routeInfo);
                      },
                    ))
                .toList(),
          ),
        ],
      ),
    );
  }
}
