import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:slick/configuration/slick_configuration.dart';
import 'package:slick/controls/slick_scaffold.dart';
import 'package:slick/navigation/route_configuration.dart';

class BaseScreen extends ConsumerWidget {
  @override
  Widget build(BuildContext context, ScopedReader watch) {
    currentRouteSingleton.building = true;
    var provider = currentRouteSingleton.logicForRoute();

    Widget bodyWidget;
    if (provider != null) {
      var baseLogic = watch(provider);
      if (baseLogic == null) return SlickConfiguration.unknownScreen;
      if (!baseLogic.hasViewAccess) {
        baseLogic.setError('You don\'t have permission for this route');
      }

      if (currentRouteSingleton.reInit) {
        baseLogic.deactivate();
      }

      if (currentRouteSingleton.reInit ||
          (!baseLogic.ready && !baseLogic.hasError)) baseLogic.init();

      if (baseLogic.hasError) {
        bodyWidget =
            SlickScaffold(body: Center(child: Text('${baseLogic.error}')));
      } else if (!baseLogic.ready) {
        bodyWidget = SlickScaffold(
          body: Center(child: CircularProgressIndicator()),
        );
      } else {
        bodyWidget = currentRouteSingleton.screenForRoute();
      }
    } else {
      bodyWidget = currentRouteSingleton.screenForRoute();
    }

    currentRouteSingleton.building = false;

    return bodyWidget;
  }
}
